import TextareaAutosize from "react-textarea-autosize";
import { AddProjectButton } from "@src/components/todos/add/addProjectButton";
import { AddPriorityButton } from "@src/components/todos/add/addPriorityButton";
import { Priorities } from "@src/core/entities/todo";

export const TodoShortForm = (props: {
  project: string;
  onProjectChanged: (project: string) => void;
  priority: Priorities;
  onPriorityChanged: (project: Priorities) => void;
  name: string;
  onNameChange: (e) => void;
  description: string;
  onDescriptionChange: (e) => void;
}) => (
  <div className="flex flex-col md:flex-row gap-4">
    <div className="todo-input-form md:flex-grow py-2 px-4 dark:bg-gray-800 border border-gray-200 rounded-lg space-y-2">
      <div>
        <input
          type="text"
          required
          placeholder="Todo name"
          className="text-sm w-full"
          autoFocus
          value={props.name}
          tabIndex={1}
          onChange={props.onNameChange}
        />
      </div>
      <div className="h-px bg-gray-200 dark:bg-gray-500" />
      <div>
        <TextareaAutosize
          placeholder="Description"
          className="text-sm w-full h-full resize-none overflow-auto"
          value={props.description}
          tabIndex={2}
          onChange={props.onDescriptionChange}
          minRows={3}
        />
      </div>
      <div className="flex  flex-col sm:flex-row pb-1 gap-2 justify-between">
        <div>
          <AddProjectButton
            onProjectChanged={props.onProjectChanged}
            initialProject={props.project}
          >
            {props.project}
          </AddProjectButton>
        </div>

        <div>
          <AddPriorityButton
            onPriorityChanged={props.onPriorityChanged}
            initialPriority={props.priority}
          >
            {props.priority}
          </AddPriorityButton>
        </div>
      </div>
    </div>
  </div>
);
